using System;
using System.Collections.Generic;
using System.Text;
using System.Drawing;
using System.ComponentModel;
using Utils.Misc;
using System.Runtime.Serialization;
using System.IO;
using Components.TypeEditors;
using System.Drawing.Design;
using System.Data.OleDb;
using System.Data;
using System.Windows.Forms;
using PhoenixDLL.RegistryConfiguration;
using Components.TypeEditors.GUI;
using System.Drawing.Printing;

namespace PhoenixDLL.Class
{
    #region Delegate
    /// <summary>
    /// Handler d'vnement de changement d'options
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>    
    public delegate void OnOptionChangedHandler(object sender, EventArgs e);
    #endregion

    /// <summary>
    /// Classe d'options
    /// </summary>
    [Serializable]
    public class Options : Serializer, IDisposable
    {
        #region Variables
        /// <summary>
        /// Premier dmarrage des options
        /// </summary>
        private bool vFirstInstance = true;

        #region Singletton
        /// <summary>
        /// Rfrence sur le singletton
        /// </summary>        
        private static Options refOptions = null;
        #endregion

        #region MonthAgenda
        /// <summary>
        /// Couleur de fond du header
        /// </summary>
        protected Color vHeaderBackColor = Color.White;
        /// <summary>
        /// Couleur du texte du header
        /// </summary>
        protected Color vHeaderTextColor = Color.Black;
        /// <summary>
        /// Police d'criture du header
        /// </summary>
        protected Font vHeaderTextFont = new Font("Times New Roman", 12);

        /// <summary>
        /// Couleur de fond du HeaderDay
        /// </summary>
        protected Color vHeaderDayBackColor = Color.White;
        /// <summary>
        /// Couleur d'criture du HeaderDay
        /// </summary>
        protected Color vHeaderDayTextColor = Color.Black;
        /// <summary>
        /// Police d'criture du HeaderDay
        /// </summary>
        protected Font vHeaderDayFont = new Font("Times New Roman", 12);

        /// <summary>
        /// Couleur de font des jours
        /// </summary>
        protected Color vDaysBackColor = Color.White;
        /// <summary>
        /// Couleur d'criture des jours
        /// </summary>
        protected Color vDaysTextColor = Color.Black;
        /// <summary>
        /// Couleur de la bordure qui spare les jours
        /// </summary>
        protected Color vDaysBorderColor = Color.Silver;
        /// <summary>
        /// Couleur des jours qui sont hors du mois
        /// </summary>
        protected Color vDaysNonInMonthColor = Color.Silver;
        /// <summary>
        /// Police d'criture des jours
        /// </summary>
        protected Font vDaysFont = new Font("Times New Roman", 12);

        /// <summary>
        /// Couleur de aujourd'hui
        /// </summary>
        protected Color vToday = Color.Tomato;
        #endregion

        #region DayAgenda
        /// <summary>
        /// Couleur de dgrad
        /// </summary>
        protected Color vFadeColor = Color.Silver;
        /// <summary>
        /// Couleur de fond d'un rendez-vous
        /// </summary>
        protected Color vMeetingBackColor = Color.PeachPuff;
        /// <summary>
        /// Couleur du texte des rendez-vous
        /// </summary>
        protected Color vMeetingTextColor = Color.Black;
        /// <summary>
        /// Couleur de la police d'criture 
        /// </summary>
        protected Font vMeetingTextFont = new Font("Times New Roman", 12);
        /// <summary>
        /// Couleur de fond des non rendez-vous
        /// </summary>
        protected Color vNonMeetingBackColor = Color.White;

        #endregion

        #region Base de donnes
        /// <summary>
        /// Chemin de la base de donnes
        /// </summary>
        protected string vBDPath = ApplicationPath.CommandPath + "\\GestionPatient.mdb";
        #endregion

        #region SMTP
        /// <summary>
        /// Mot de passe du serveur SMTP pour l'envois d'erreur
        /// </summary>
        protected string vSMTPPassword = "";

        /// <summary>
        /// Addresse du server SMTP pour l'envoi des messages d'erreurs
        /// </summary>
        protected string vSMTPServer = "";

        /// <summary>
        /// Port de communication du serveur SMTP
        /// </summary>
        protected int vSMTPPort = 25;
        #endregion

        #region Impression
        /// <summary>
        /// Entte pour l'impression des prescriptions
        /// </summary>
        private string vPrintPrescriptionHeader = "";
        /// <summary>
        /// Police de caractre pour le header de prescriptions
        /// </summary>
        private Font vPrintPrescriptionFont = new Font("Times New Roman", 8);
        /// <summary>
        /// Informations sur l'impression des prescriptions
        /// </summary>
        private PrinterSettings vPrinterSettingsPrescriptions = new PrinterSettings();

        #endregion

        #region Fiche mdicale
        /// <summary>
        /// Titre de la fiche supplmentaire 1
        /// </summary>
        protected string vAdditionnalTitle1 = "Fiche 1";

        /// <summary>
        /// Titre de la fiche supplmentaire 2
        /// </summary>
        protected string vAdictionnalTitle2 = "Fiche 2";

        /// <summary>
        /// Titre de la fiche supplmentaire 3
        /// </summary>
        protected string vAdditionnalTitle3 = "Fiche 3";

        /// <summary>
        /// Titre de la fiche supplmentaire 4
        /// </summary>
        protected string vAdditionnalTitle4 = "Fiche 4";

        /// <summary>
        /// Vivibilit de la fiche 1
        /// </summary>
        protected bool vIsVisible1 = false;

        /// <summary>
        /// Vivibilit de la fiche 2
        /// </summary>
        protected bool vIsVisible2 = false;

        /// <summary>
        /// Vivibilit de la fiche 3
        /// </summary>
        protected bool vIsVisible3 = false;

        /// <summary>
        /// Vivibilit de la fiche 4
        /// </summary>
        protected bool vIsVisible4 = false;
        #endregion

        #region Versions
        private const string vVersion = "BETA 0.9.6";
        #endregion

        #region DeskSave
        /// <summary>
        /// Informations sur les menus de Pata
        /// </summary>
        private PataMenu vPataMenu = new PataMenu();
        /// <summary>
        /// Informations sur les menus de Pega
        /// </summary>
        private PegaMenu vPegaMenu = new PegaMenu();
        #endregion
        #endregion

        #region Constructeur
        /// <summary>
        /// Constructeur par dfaut
        /// </summary>
        protected Options()
            : base(ApplicationPath.CommandPath + "\\Options.srz") { }

        /// <summary>
        /// Constructeur par dfaut
        /// </summary>
        /// <param name="_Path">Path du fichier d'options</param>
        protected Options(string _Path) : base(_Path) { }

        /// <summary>
        /// Destructeur
        /// </summary>
        ~Options() { base.Serialize(this); }

        /// <summary>
        /// Mthode factory qui retourne une rfrence sur l'objet Options
        /// </summary>
        /// <returns>Une rfrence sur l'objet Options</returns>
        public static Options GetInstance()
        {
            string path = RegistryManager.GetOptionsPath();
            if (refOptions == null)
            {
                try
                { refOptions = (Options)Deserialize(path); }

                catch (FileNotFoundException) { refOptions = new Options(path); }
                catch (Exception ex) { throw new Exception("GetInstance() " + ex.Message); }
            }
            return refOptions;
        }
        #endregion

        #region Accesseurs
        #region MonthAgenda
        /// <summary>
        /// Retourne ou initialise la couleur de font du header
        /// </summary>
        [Category("Affichage du mois - Header")]
        [Description("Initialise la couleur de font du header")]
        [DisplayName("Couleur de fond du header")]
        public Color HeaderBackColor
        {
            get { return vHeaderBackColor; }
            set { vHeaderBackColor = value; }
        }

        /// <summary>
        /// Retourne ou initialise la couleur du texte du header
        /// </summary>
        [Category("Affichage du mois - Header")]
        [Description("Initialise la couleur du texte du header")]
        [DisplayName("Couleur du texte du header")]
        public Color HeaderTextColor
        {
            get { return vHeaderTextColor; }
            set { vHeaderTextColor = value; }
        }

        /// <summary>
        /// Retourne ou initialise la police de caractre du header
        /// </summary>
        [Category("Affichage du mois - Header")]
        [Description("Initialise la police du texte du header")]
        [DisplayName("Police du header")]
        public Font HeaderTextFont
        {
            get { return vHeaderTextFont; }
            set { vHeaderTextFont = value; }
        }

        /// <summary>
        /// Retourne ou initialise la couleur de fond du header des jours
        /// </summary>
        [Category("Affichage du mois - Header Jours")]
        [Description("Initialise la couleur de fond du header des jours")]
        [DisplayName("Couleur de fond du header de jour")]
        public Color HeaderDayBackColor
        {
            get { return vHeaderDayBackColor; }
            set { vHeaderDayBackColor = value; }
        }

        /// <summary>
        /// Retourne ou initialise la couleur du texte du header des jours
        /// </summary>
        [Category("Affichage du mois - Header Jours")]
        [Description("Initialise la couleur du texte du header des jours")]
        [DisplayName("Couleur du texte du header de jour")]
        public Color HeaderDayTextColor
        {
            get { return vHeaderDayTextColor; }
            set { vHeaderDayTextColor = value; }
        }

        /// <summary>
        /// Retourne ou initialise la police d'criture du header des jours
        /// </summary>
        [Category("Affichage du mois - Header Jours")]
        [Description("Initialise la police d'criture du header des jours")]
        [DisplayName("Police du header de jour")]
        public Font HeaderDayTextFont
        {
            get { return vHeaderDayFont; }
            set { vHeaderDayFont = value; }
        }

        /// <summary>
        /// Retourne ou initialise la couleur de fond des jours
        /// </summary>
        [Category("Affichage du mois - Jours")]
        [Description("Initialise la couleur de fond des jours")]
        [DisplayName("Couleur de fond des jours")]
        public Color DaysBackColor
        {
            get { return vDaysBackColor; }
            set { vDaysBackColor = value; }
        }

        /// <summary>
        /// Retourne ou initialise la couleur de fond des jours
        /// </summary>
        [Category("Affichage du mois - Jours")]
        [Description("Initialise la couleur de fond des jours")]
        [DisplayName("Couleur du texte de jours")]
        public Color DaysTextColor
        {
            get { return vDaysTextColor; }
            set { vDaysTextColor = value; }
        }

        /// <summary>
        /// Retourne ou initialise la couleur de la bordure des jours
        /// </summary>
        [Category("Affichage du mois - Jours")]
        [Description("Initialise la couleur de la bordure des jours")]
        [DisplayName("Couleur de la bordure des jours")]
        public Color DaysBorderColor
        {
            get { return vDaysBorderColor; }
            set { vDaysBorderColor = value; }
        }

        /// <summary>
        /// Retourne ou initialise le couleur de fond des jours hors du mois
        /// </summary>
        [Category("Affichage du mois - Jours")]
        [Description("Initialise le couleur de fond des jours hors du mois")]
        [DisplayName("Couleurs des jours hors mois")]
        public Color DaysNonInMonthColor
        {
            get { return vDaysNonInMonthColor; }
            set { vDaysNonInMonthColor = value; }
        }

        /// <summary>
        /// Retourne ou initialise la police d'affichage des jours
        /// </summary>
        [Category("Affichage du mois - Jours")]
        [Description("Initialise la police d'affichage des jours")]
        [DisplayName("Police des jours")]
        public Font DaysTextFont
        {
            get { return vDaysFont; }
            set { vDaysFont = value; }
        }


        /// <summary>
        /// Retourne ou initialise la couleur du jour d'aujourd'hui
        /// </summary>
        [Category("Affichage du mois - Aujourd'hui")]
        [Description("Initialise la couleur du jour d'aujourd'hui")]
        [DisplayName("Couleur d'aujourd'hui")]
        public Color TodayBackColor
        {
            get { return vToday; }
            set { vToday = value; }
        }
        #endregion

        #region DayAgenda
        /// <summary>
        /// Retourne ou initialise la premire couleur de fondu pour le rendez-vous
        /// </summary>
        [Category("Affichage du jour")]
        [Description("Initialise le couleur de fondu pour le rendez-vous")]
        [DisplayName("Couleur 1 de fondu d'un rendez-vous")]
        public Color FirstMeetingFadeColor
        {
            get { return vFadeColor; }
            set { vFadeColor = value; }
        }

        /// <summary>
        /// Retourne ou initialise la deuxime couleur de fond d'un rendez-vous
        /// </summary>
        [Category("Affichage du jour")]
        [Description("Initialise la deuxime couleur de fond d'un rendez-vous")]
        [DisplayName("Couleur 2 de fondu d'un rendez-vous")]
        public Color SecondMeetingFadeColor
        {
            get { return vMeetingBackColor; }
            set { vMeetingBackColor = value; }
        }

        /// <summary>
        /// Retourne ou initialise la couleur d'criture dans un rendez-vous
        /// </summary>
        [Category("Affichage du jour")]
        [Description("Initialise la couleur d'criture dans un rendez-vous")]
        [DisplayName("Couleur d'criture dans un rendez-vous")]
        public Color MeetingTextColor
        {
            get { return vMeetingTextColor; }
            set { vMeetingTextColor = value; }
        }

        /// <summary>
        /// Retourne ou initialise la police d'criture d'un rendez-vous
        /// </summary>
        [Category("Affichage du jour")]
        [Description("Initialise la police d'criture d'un rendez-vous")]
        [DisplayName("Police d'criture dans un rendez-vous")]
        public Font MeetingTextFont
        {
            get { return vMeetingTextFont; }
            set { vMeetingTextFont = value; }
        }

        /// <summary>
        /// Retourne ou initialise la couleur d'affichage d'une heure hors rendez-vous
        /// </summary>
        [Category("Affichage du jour")]
        [Description("Initialise la couleur d'affichage d'une heure hors rendez-vous")]
        [DisplayName("Couleur de fond d'une heure sans rendez-vous")]
        public Color NonMeetingBackColor
        {
            get { return vNonMeetingBackColor; }
            set { vNonMeetingBackColor = value; }
        }
        #endregion

        #region Base de donnes
        /// <summary>
        /// Retourne ou initialise le path de la base de donnes.
        /// </summary>
        /// <exception cref="FileNotFoundException">Si le fichier n'existe pas</exception>
        [Category("Base de donnes")]
        [DisplayName("[Expert] Chemin de la base de donnes")]
        [Description("[Expert] Initialise le path de la base de donnes")]
        [Editor(typeof(UIPathEditor), typeof(UITypeEditor))]
        public string Path
        {
            get { return vBDPath; }
            set
            {
                if (File.Exists(value))
                    vBDPath = value;
                else
                    throw new FileNotFoundException("Le fichier indiqu n'existe pas!", value);
            }
        }
        #endregion

        #region Miscelanious
        /// <summary>
        /// Retourne ou initialise le mot de passe du serveur SMTP
        /// </summary>
        [Category("SMTP")]
        [DisplayName("[Expert] Mot de passe du serveur SMTP")]
        [Description("[Expert] Indique le mot de passe du serveur SMTP pour l'envois de mails en cas d'erreur")]

        [PasswordPropertyText(true)]
        public string SMTPPassword
        {
            get { return vSMTPPassword; }
            set { vSMTPPassword = value; }
        }

        /// <summary>
        /// Retourne ou initialise l'adresse du serveur SMTP
        /// </summary>
        [Category("SMTP")]
        [DisplayName("[Expert] Serveur SMTP")]
        [Description("[Expert] Indique le serveur SMTP pour l'envois de mails en cas d'erreur")]
        public string SMTPServer
        {
            get { return vSMTPServer; }
            set { vSMTPServer = value; }
        }

        /// <summary>
        /// retourne ou initialise le port de communication du serveur SMTP
        /// </summary>
        [Category("SMTP")]
        [DisplayName("[Expert] Port de communication du serveur SMTP")]
        [Description("Initialise le port de communicaiton du serveur SMTP")]
        [DefaultValue(25)]
        public int SMTPPort
        {
            get { return vSMTPPort; }
            set { vSMTPPort = value; }// 25; }
        }
        #endregion

        #region Fiches mdicales
        /// <summary>
        /// Retourne ou initialise la titre de la fiche supplmentaire 1
        /// </summary>
        [Category("Fiches supplmentaires")]
        [DisplayName("Titre de la fiche 1")]
        [Description("Initialise le titre de la fiche optionnelle 1")]
        public string AdditionnalTitle1
        {
            get { return vAdditionnalTitle1; }
            set
            {
                vAdditionnalTitle1 = value;
                OnOptionChanged(new EventArgs());
            }
        }

        /// <summary>
        /// Retourne ou initialise la titre de la fiche supplmentaire 2
        /// </summary>
        [Category("Fiches supplmentaires")]
        [DisplayName("Titre de la fiche 2")]
        [Description("Initialise le titre de la fiche optionnelle 2")]
        public string AdditionnalTitle2
        {
            get { return vAdictionnalTitle2; }
            set
            {
                vAdictionnalTitle2 = value;
                OnOptionChanged(new EventArgs());
            }
        }

        /// <summary>
        /// Retourne ou initialise la titre de la fiche supplmentaire 3
        /// </summary>
        [Category("Fiches supplmentaires")]
        [DisplayName("Titre de la fiche 3")]
        [Description("Initialise le titre de la fiche optionnelle 3")]
        public string AdditionnalTitle3
        {
            get { return vAdditionnalTitle3; }
            set
            {

                vAdditionnalTitle3 = value;
                OnOptionChanged(new EventArgs());
            }
        }

        /// <summary>
        /// Retourne ou initialise la titre de la fiche supplmentaire 4
        /// </summary>
        [Category("Fiches supplmentaires")]
        [DisplayName("Titre de la fiche 4")]
        [Description("Initialise le titre de la fiche optionnelle 4")]
        public string AdditionnalTitle4
        {
            get { return vAdditionnalTitle4; }
            set
            {
                vAdditionnalTitle4 = value;
                OnOptionChanged(new EventArgs());
            }
        }

        /// <summary>
        /// Retourne ou initialise la fait que le fiche supplmentaire 1 est visible ou pas
        /// </summary>
        [Category("Fiches supplmentaires")]
        [DisplayName("Visibilit de la fiche supplmentaire 1")]
        [Description("Indique si cette fiche supplmentaire doit tre visible ou pas")]
        public bool IsVisible1
        {
            get { return vIsVisible1; }
            set
            {
                if (CountCardNumber(1) == 0)
                    vIsVisible1 = value;
                else
                {
                    ClearCardNumber(1, value);
                    vIsVisible1 = value;
                }
                OnOptionChanged(new EventArgs());
            }
        }

        /// <summary>
        /// Retourne ou initialise la fait que le fiche supplmentaire 2 est visible ou pas
        /// </summary>
        [Category("Fiches supplmentaires")]
        [DisplayName("Visibilit de la fiche supplmentaire 2")]
        [Description("Indique si cette fiche supplmentaire doit tre visible ou pas")]
        public bool IsVisible2
        {
            get { return vIsVisible2; }
            set
            {
                if (CountCardNumber(2) == 0)
                    vIsVisible2 = value;
                else
                {
                    ClearCardNumber(2, value);
                    vIsVisible2 = value;
                }
                OnOptionChanged(new EventArgs());
            }
        }

        /// <summary>
        /// Retourne ou initialise la fait que le fiche supplmentaire 3 est visible ou pas
        /// </summary>
        [Category("Fiches supplmentaires")]
        [DisplayName("Visibilit de la fiche supplmentaire 3")]
        [Description("Indique si cette fiche supplmentaire doit tre visible ou pas")]
        public bool IsVisible3
        {
            get { return vIsVisible3; }
            set
            {
                if (CountCardNumber(3) == 0)
                    vIsVisible3 = value;
                else
                {
                    ClearCardNumber(3, value);
                    IsVisible3 = value;
                }
                OnOptionChanged(new EventArgs());
            }
        }

        /// <summary>
        /// Retourne ou initialise la fait que le fiche supplmentaire 4 est visible ou pas
        /// </summary>
        [Category("Fiches supplmentaires")]
        [DisplayName("Visibilit de la fiche supplmentaire 4")]
        [Description("Indique si cette fiche supplmentaire doit tre visible ou pas")]
        public bool IsVisible4
        {
            get { return vIsVisible4; }
            set
            {
                if (CountCardNumber(4) == 0)

                    vIsVisible4 = value;
                else
                {
                    ClearCardNumber(4, value);
                    vIsVisible4 = value;
                }
                OnOptionChanged(new EventArgs());
            }
        }
        #endregion

        #region Impression
        /// <summary>
        /// Retourne ou initialise le texte pour l'entte d'impression des prescriptions
        /// </summary>
        [Category("Impressions - Prescriptions")]
        [DisplayName("Texte d'entte des prescriptions")]
        [Description("Initialise le texte pour l'entte d'impression des prescriptions")]
        [Editor(typeof(UILongTextEditor), typeof(UITypeEditor))]
        public string PrintPrescriptionHeader
        {
            get { return vPrintPrescriptionHeader; }
            set { vPrintPrescriptionHeader = value; }
        }

        /// <summary>
        /// Retourne ou initialise la police d'criture du headr de prescription
        /// </summary>
        [Category("Impressions - Prescriptions")]
        [DisplayName("Police de caractre d'entte des prescriptions")]
        [Description("Initialise la police d'criture du headr de prescription")]
        //[Editor(typeof(UILongTextEditor), typeof(UITypeEditor))]
        public Font FontPrescriptionHeader
        {
            get { return vPrintPrescriptionFont; }
            set { vPrintPrescriptionFont = value; }
        }

        /// <summary>
        /// Retourne ou initialise les options d'impressions d'une prescription
        /// </summary>
        [Browsable(false)]
        public PrinterSettings PrinterSettingsPrescritions
        {
            get { return vPrinterSettingsPrescriptions; }
            set { vPrinterSettingsPrescriptions = value; }
        }
        #endregion

        #region Versions
        /// <summary>
        /// Retourne ou initialise la valeur qui indique si c'est la premire fois que l'on instancie le fichier d'options
        /// </summary>
        [Browsable(false)]
        public bool IsFirstInstance { get { return this.vFirstInstance; } set { vFirstInstance = value; } }
        /// <summary>
        /// Retourne la version de Cala
        /// </summary>
        [Browsable(false)]
        public string Version { get { return vVersion; } }
        /// <summary>
        /// Retourne une instance de Options
        /// </summary>
        [Browsable(false)]
        public static Options Instance { get { return GetInstance(); } }
        #endregion

        #region DeskSave
        /// <summary>
        /// Retourne ou initialise les informations de visibilit des menus de Pata
        /// </summary>
        [Browsable(false)]
        public PataMenu PataMenu { get { return vPataMenu; } set { vPataMenu = value; } }
        /// <summary>
        /// Retourne ou initialise les informations de visibilit des menus de Pega
        /// </summary>
        [Browsable(false)]
        public PegaMenu PegaMenu { get { return vPegaMenu; } set { vPegaMenu = value; } }
        #endregion
        #endregion

        #region IDisposable Members
        /// <summary>
        /// Fait une destruction de l'objet
        /// </summary>
        public void Dispose()
        {
            base.Serialize(this);
        }
        #endregion

        #region Events
        [NonSerialized]
        private OnOptionChangedHandler DelegateOptionChangedHandler;

        /// <summary>
        /// Se produit lorsqu'il y a eu un changement d'option  traiter
        /// </summary>
        [Browsable(false)]
        public event OnOptionChangedHandler OptionChanged
        {
            add { DelegateOptionChangedHandler += value; }
            remove { DelegateOptionChangedHandler -= value; }
        }

        /// <summary>
        /// Notifie une demande de notify pour l'vnement d'options change
        /// </summary>
        /// <param name="args"></param>                
        protected virtual void OnOptionChanged(EventArgs args)
        {
            if (DelegateOptionChangedHandler != null)
                DelegateOptionChangedHandler(this, args);

        }
        #endregion

        #region Mthodes
        /// <summary>
        /// Compte le nombre de fiches optionnelles qui ont des informations...
        /// </summary>
        /// <param name="_CardNumber">Numro de la fiche optionnelle</param>
        /// <returns>le nombre de fiche remplis</returns>
        protected int CountCardNumber(int _CardNumber)
        {
            string conStr = "Provider=Microsoft.Jet.OLEDB.4.0;Data Source=\"";
            string vPath = Options.GetInstance().Path;
            string st = conStr + vPath + "\"";

            OleDbConnection oConn = new OleDbConnection(st);
            OleDbCommand oCom;

            switch (_CardNumber)
            {
                case 1:
                    oCom = new OleDbCommand("COUNT_FicheSupp1", oConn);
                    break;
                case 2:
                    oCom = new OleDbCommand("COUNT_FicheSupp2", oConn);
                    break;
                case 3:
                    oCom = new OleDbCommand("COUNT_FicheSupp3", oConn);
                    break;
                case 4:
                    oCom = new OleDbCommand("COUNT_FicheSupp4", oConn);
                    break;
                default:
                    throw new ArgumentException("Veuillez choisir un nombre entre 1 et 4 inclus", "_CardNumber");
            }

            oCom.CommandType = CommandType.StoredProcedure;
            OleDbDataAdapter oDa = new OleDbDataAdapter(oCom);

            oConn.Open();
            int i = (int)oCom.ExecuteScalar(); //ExecuteNonQuery();
            oConn.Close();

            return i;
        }

        /// <summary>
        /// Supprime le contenu de la fiche de numro donn en argument
        /// </summary>
        /// <param name="_CardNumber">Numro de la fiche  nettoyer</param>
        /// <param name="_IsSkipped">Faut-il faire le traitement?</param>
        protected void ClearCardNumber(int _CardNumber, bool _IsSkipped)
        {
            if (_IsSkipped)
            {
                DialogResult dr = MessageBox.Show("Cette fiche contient dj des informations."
                + "Faut-il toutes les effacer?", "Question", MessageBoxButtons.YesNo, MessageBoxIcon.Question);

                if (dr == DialogResult.Yes)
                {
                    string conStr = "Provider=Microsoft.Jet.OLEDB.4.0;Data Source=\"";
                    string vPath = Options.GetInstance().Path;
                    string st = conStr + vPath + "\"";

                    OleDbConnection oConn = new OleDbConnection(st);
                    OleDbCommand oCom;

                    switch (_CardNumber)
                    {
                        case 1:
                            oCom = new OleDbCommand("CLEAR_FicheSupp1", oConn);
                            break;
                        case 2:
                            oCom = new OleDbCommand("CLEAR_FicheSupp2", oConn);
                            break;
                        case 3:
                            oCom = new OleDbCommand("CLEAR_FicheSupp3", oConn);
                            break;
                        case 4:
                            oCom = new OleDbCommand("CLEAR_FicheSupp4", oConn);
                            break;
                        default:
                            throw new ArgumentException("Veuillez choisir un nombre entre 1 et 4 inclus", "_CardNumber");
                    }

                    oCom.CommandType = CommandType.StoredProcedure;
                    OleDbDataAdapter oDa = new OleDbDataAdapter(oCom);

                    oConn.Open();
                    oCom.ExecuteNonQuery();
                    oConn.Close();
                }
            }
        }

        #endregion
    }

    /// <summary>
    /// Indique les menu qui sont actif dans Pata
    /// </summary>
    [Serializable]
    public class PataMenu
    {
        /// <summary>
        /// Constructeur
        /// </summary>
        public PataMenu() { }
        /// <summary>
        /// Indique si le menu PageStyle est visible
        /// </summary>
        public bool PageStyleVisible = false;
        /// <summary>
        /// Indique su le menu SeekCancel est visible
        /// </summary>
        public bool SeekCancelVisible = false;
        /// <summary>
        /// Indique si le menu General est visible
        /// </summary>
        public bool GeneralVisible = false;
    }
    /// <summary>
    /// Indique les menu qui sont actif dans Pega
    /// </summary>
    [Serializable]
    public class PegaMenu
    {
        /// <summary>
        /// Constructeur
        /// </summary>
        public PegaMenu() { }
        /// <summary>
        /// Indique si le menu de gestion doit tre visible ou non
        /// </summary>
        public bool ManagmentVisible = false;
    }
}
